@@ -8,13 +8,15 @@
 
 .Logistic <- function()
     list(p = plogis, d = dlogis, q = qlogis,
-         dd = function(x) 
-             (exp(x) - exp(2*x)) / (1 + exp(x))^3,
-         ddd = function(x) 
-             (exp(x) - 4*(exp(2*x)) + exp(3*x)) / (1 + exp(x))^4, 
+         dd = function(x) {
+             ex <- exp(x)
+             (ex - exp(2 * x)) / (1 + ex)^3
+         },
+         ddd = function(x) {
+             ex <- exp(x)
+             (ex - 4*(exp(2 * x)) + exp(3 * x)) / (1 + ex)^4
+         },
          name = "logistic")
-#         (2 * exp(-x)^2 / (1 + exp(-x))^3) - 
-#          (exp(-x) / (1 + exp(-x))^2))
 
 .MinExtrVal <- function()
     list(p = function(x) 1 - exp(-exp(x)),
@@ -24,10 +26,14 @@
              if (!log) return(exp(ret))
              ret
          },
-         dd = function(x)
-             (exp(x) - exp(2*x)) / exp(exp(x)),
-         ddd = function(x)
-             (exp(x) - 3*exp(2*x) + exp(3*x)) / exp(exp(x)),
+         dd = function(x) {
+             ex <- exp(x)
+             (ex - exp(2 * x)) / exp(ex)
+         },
+         ddd = function(x) {
+             ex <- exp(x)
+             (ex - 3*exp(2 * x) + exp(3 * x)) / exp(ex)
+         },
          name = "minimum extreme value")
 
 .distr <- function(which = c("Normal", "Logistic", 
