@@ -44,8 +44,8 @@
 ..mlt_score_interval <- function(d, mml, mmr, offset = 0, beta)
     (.dealinf(mmr, beta, offset, d$d, 0, Xmult = TRUE) -
      .dealinf(mml, beta, offset, d$d, 0, Xmult = TRUE)) / 
-    (.dealinf(mmr, beta, offset, d$p, 1) - 
-     .dealinf(mml, beta, offset, d$p, 0)) 
+    pmax(.Machine$double.eps^(1/3), (.dealinf(mmr, beta, offset, d$p, 1) - 
+     .dealinf(mml, beta, offset, d$p, 0)))
 
 .mlt_score_interval <- function(d, mml, mmr, offset = 0, mmtrunc = NULL) {
     if (is.null(mmtrunc))
