@@ -3,13 +3,14 @@ library("mlt")
 set.seed(29)
 
 n <- 20
-### design has rank deficit; just for interface checking
+### just for interface checking
 ### we need something better!
-d <- data.frame(x1 = 1:n, x2 = 1:n + 1, y = rnorm(n))
+d <- data.frame(x1 = 1:n, x2 = sample(1:n) + 1, y = rnorm(n))
 m <- ctm(polynomial_basis(numeric_var("y", support = range(d$y)),
                             coef = c(TRUE, TRUE), ci = c(-Inf, 0)),
            shift = ~ x1 + x2, data = d)
 mod <- mlt(m, data = d)
+coef(mod)
 
 p <- predict(mod, newdata = d)
 
@@ -19,10 +20,10 @@ p1 <- predict(mod, newdata = d[, c("x1", "x2")], q = q)
 p2 <- predict(mod, newdata = d[, c("x1", "x2")], K = K)
 stopifnot(all.equal(p1, p2))
 
-(p0 <- predict(mod$model$model, 
-    newdata = expand.grid(d), coef = coef(mod)))
-(p1 <- predict(mod, newdata = as.list(d)))
-(p2 <- predict(mod, newdata = d, q = d$y[1]))
+p0 <- predict(mod$model$model, 
+    newdata = expand.grid(d), coef = coef(mod))
+p1 <- predict(mod, newdata = as.list(d))
+p2 <- predict(mod, newdata = d, q = d$y[1])
 
 max(abs(p0 - as.vector(p1)))
 
